/*** TVPIP320PIV1 Z-Way HA module *******************************************

Version: 1.0.0
(c) Z-Wave.Me, 2013
-----------------------------------------------------------------------------
Author: Stanislav Morozov <r3b@seoarmy.ru>
Description:
    This module stores params of TVPIP320PIV1

******************************************************************************/

// ----------------------------------------------------------------------------
// --- Class definition, inheritance and setup
// ----------------------------------------------------------------------------

function TVPIP320PIV1 (id, controller) {
    // Call superconstructor first (AutomationModule)
    TVPIP320PIV1.super_.call(this, id, controller);
}

inherits(TVPIP320PIV1, AutomationModule);

_module = TVPIP320PIV1;

// ----------------------------------------------------------------------------
// --- Module insTVPIP320PIV1tance initialized
// ----------------------------------------------------------------------------

_.extend(TVPIP320PIV1.prototype, {
    init: function (config) {
        TVPIP320PIV1.super_.prototype.init.call(this, config);
		
        var self = this,
            vDevId = "CameraDevice_" + this.id;
        
        this.proxy_url 	= "/" + vDevId + "/stream";

        //concat authentication
        //var authent = config.user + ":" + config.password + "@";
        
        var opener = function(command) {
            config.doorDevices.forEach(function(el) {
                var vDev = self.controller.devices.get(el);
                
                if (vDev) {
                    var type = vDev.get("deviceType");
                    if (type === "switchBinary") {
                        vDev.performCommand(command == "open" ? "on" : "off");
                    } else if (type === "doorlock") {
                            vDev.performCommand(command);
                    }
                }
            });
        };

        //stream with authentication?
        //this.url = "http://" + config.url + "/Streaming/channels/1/httpPreview?user=admin&password=innovus2008";
        
        //stream without authentication
        this.url = "http://" + config.url + "/Streaming/channels/1/httpPreview";      
        
        //proxy with authentication
        ws.proxify(this.proxy_url, this.url, config.user, config.password);
		
        //proxy without authentication
        //ws.proxify(this.proxy_url, this.url);
        
        //create cam device
        this.vDev = this.controller.devices.create({
            deviceId: vDevId,
            defaults: {
                deviceType: "camera",
                metrics: {
                    icon: 'camera',
                    title: 'TVPIP320PIV1 ' + this.id
                }
            },
            overlay: {
                metrics: {
                    url: this.proxy_url                 
                }
            },    
            moduleId: this.id
        });
    },
    stop: function () {
        TVPIP320PIV1.super_.prototype.stop.call(this);

        ws.proxify(this.proxy_url, null);
        
        if (this.vDev) {
            this.controller.devices.remove(this.vDev.id);
            this.vDev = null;
        }
    }
});
